==> libtorrent-0.7.0.tar.gz: libtorrent-0.7.0/src/torrent/rate.cc <==
// libTorrent - BitTorrent library
// Copyright (C) 2005, Jari Sundell
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// In addition, as a special exception, the copyright holders give
// permission to link the code of portions of this program with the
// OpenSSL library under certain conditions as described in each
// individual source file, and distribute linked combinations
// including the two.
//
// You must obey the GNU General Public License in all respects for
// all of the code used other than OpenSSL.  If you modify file(s)
// with this exception, you may extend this exception to your version
// of the file(s), but you are not obligated to do so.  If you do not
// wish to do so, delete this exception statement from your version.
// If you delete this exception statement from all source files in the
// program, then also delete it here.
//
// Contact:  Jari Sundell <jaris@ifi.uio.no>
//
//           Skomakerveien 33
//           3185 Skoppum, NORWAY

#include "config.h"

#include "rate.h"
#include "utils/timer.h"

namespace torrent {

inline void
Rate::discard_old() const {
  while (!m_container.empty() &&
	 m_container.back().first < Timer::cache().seconds() - m_span) {
    m_current -= m_container.back().second;
    m_container.pop_back();
  }
}

uint32_t
Rate::rate() const {
  discard_old();

  //  return m_current / std::max<uint32_t>(10, data_time_span());
  return m_current / m_span;
}

void
Rate::insert(uint32_t bytes) {
  discard_old();

  if (m_container.empty() ||
      m_container.front().first != Timer::cache().seconds())
    m_container.push_front(value_type(Timer::cache().seconds(), bytes));
  else
    m_container.front().second += bytes;

  m_total += bytes;
  m_current += bytes;
}
  

}

==> libtorrent-0.8.3.tar.gz: libtorrent-0.8.3/src/torrent/rate.cc <==
// libTorrent - BitTorrent library
// Copyright (C) 2005-2006, Jari Sundell
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// In addition, as a special exception, the copyright holders give
// permission to link the code of portions of this program with the
// OpenSSL library under certain conditions as described in each
// individual source file, and distribute linked combinations
// including the two.
//
// You must obey the GNU General Public License in all respects for
// all of the code used other than OpenSSL.  If you modify file(s)
// with this exception, you may extend this exception to your version
// of the file(s), but you are not obligated to do so.  If you do not
// wish to do so, delete this exception statement from your version.
// If you delete this exception statement from all source files in the
// program, then also delete it here.
//
// Contact:  Jari Sundell <jaris@ifi.uio.no>
//
//           Skomakerveien 33
//           3185 Skoppum, NORWAY

#include "config.h"

#include "globals.h"
#include "rate.h"

namespace torrent {

inline void
Rate::discard_old() const {
  while (!m_container.empty() &&
	 m_container.back().first < cachedTime.seconds() - (int32_t)m_span) {
    m_current -= m_container.back().second;
    m_container.pop_back();
  }
}

uint32_t
Rate::rate() const {
  discard_old();

  //  return m_current / std::max<uint32_t>(10, data_time_span());
  return m_current / m_span;
}

void
Rate::insert(uint32_t bytes) {
  discard_old();

  if (m_container.empty() ||
      m_container.front().first != cachedTime.seconds())
    m_container.push_front(value_type(cachedTime.seconds(), bytes));
  else
    m_container.front().second += bytes;

  m_total += bytes;
  m_current += bytes;
}
  

}
